@@ -35,16 +35,17 @@ class geturl:
         for link in all_url:
             if is_external == 0:
                 if (link.startswith('http')) and (link not in self.url_list) and (domain in link) and \
-                        (len(url_list) < int(count)) and ((int(time.time()) - self.start_time) < int(timeout)):
+                        (len(self.url_list) < int(count)) and ((int(time.time()) - self.start_time) < int(timeout)):
                     self.url_list.append(link)
+                    print(link)
                     f = open('url.txt', 'a+', encoding='utf-8')
                     f.write(str(link) + '\n')
                     f.close()
                     print(link)
                     self.request(link, domain,  timeout, count, is_external)
             else:
-                if (link.startswith('http')) and (link not in self.url_list)  and \
-                        (len(url_list) < int(count)) and ((int(time.time()) - self.start_time) < int(timeout)):
+                if (link.startswith('http')) and (link not in self.url_list) and \
+                        (len(self.url_list) < int(count)) and ((int(time.time()) - self.start_time) < int(timeout)):
                     self.url_list.append(link)
                     f = open('url.txt', 'a+', encoding='utf-8')
                     f.write(str(link) + '\n')
